@@ -19,7 +19,7 @@ b
 
 ## ------------------------------------------------------------------------
 x = try(units(a) <- "secs")
-x
+attr(x, "condition")[[1]]
 
 ## ------------------------------------------------------------------------
 a + a
@@ -36,6 +36,9 @@ a * t
 ## ------------------------------------------------------------------------
 signif(a^2.5, 3)
 cumsum(a)
+log(a) # base defaults to exp(1)
+log(a, base = 10)
+log(a, base = 2)
 
 ## ------------------------------------------------------------------------
 sum(a)
